/// <reference types="node" />
import type { PostGrid, PostGridOptions, PostGridError } from './';
import type { Contact } from './contact';
export interface Check {
    id: string;
    object: string;
    live: boolean;
    description?: string;
    sendDate: Date;
    to: Contact;
    from: Contact;
    url?: string;
    bankAccount: string;
    currencyCode: string;
    amount: number;
    memo?: string;
    logo?: string;
    number: number;
    message?: string;
    letterHTML?: string;
    letterTemplate?: string;
    letterUploadedPDF?: string;
    mergeVariables?: any;
    metadata?: any;
}
export interface CheckList {
    object: string;
    limit: number;
    skip: number;
    totalCount: number;
    data: Check[];
}
export declare class CheckApi {
    client: PostGrid;
    baseRoute: string;
    constructor(client: PostGrid, options?: PostGridOptions);
    get(id: string): Promise<{
        success: boolean;
        check?: Check;
        error?: PostGridError;
    }>;
    list(limit?: number, skip?: number): Promise<{
        success: boolean;
        checks?: CheckList;
        error?: PostGridError;
    }>;
    create(check: {
        description?: string;
        sendDate?: Date | string;
        to: Partial<Contact> | string;
        from: Partial<Contact> | string;
        bankAccount: string;
        currencyCode?: string;
        amount: number;
        memo?: string;
        logo?: string;
        number?: number;
        message?: string;
        letterHTML?: string;
        letterTemplate?: string;
        letterPDF?: Buffer | string;
        mergeVariables?: any;
        metadata?: any;
    }, options?: {
        idempotencyKey?: string;
    }): Promise<{
        success: boolean;
        check?: Check;
        error?: PostGridError;
        message?: string;
    }>;
    progress(id: string): Promise<{
        success: boolean;
        check?: Check;
        error?: PostGridError;
    }>;
    delete(id: string): Promise<{
        success: boolean;
        check?: Check;
        error?: PostGridError;
    }>;
}
